@@ -26,3 +26,11 @@ class Satellite(DataSourceOutput):
         )
 
         return v
+
+
+class HRVSatellite(Satellite):
+    """Class to store HRV satellite data as a xr.Dataset with some validation"""
+
+    __slots__ = ()
+    _expected_dimensions = ("time", "x", "y", "channels")
+    _expected_data_vars = ("data",)
